@@ -1,4 +1,4 @@
-﻿#ifndef BTRACE_H
+#ifndef BTRACE_H
 #define BTRACE_H
 int boundarytrace(int x1, int y1, int x2, int y2, number_t *xpos,
                   number_t *ypos);
